% clear MATLAB
clc; clear all; close all;


% load apm libraries
addpath('apm');

% server
s = 'http://xps.apmonitor.com';

% application name + random number
a = ['demo_' int2str(rand()*1000)];

% clear server
apm(s,a,'clear all');

% load model
apm_load(s,a,'nlp.apm');

% change the solver
% (1=APOPT, 2=BPOPT, 3=IPOPT)
apm_option(s,a,'nlc.solver',3);

% solve
output = apm(s,a,'solve');
disp(output)

% retrieve solution
y = apm_sol(s,a);
solution = y.x;
disp(solution)

% open application root files
apm_web_root(s,a)

% open solution in web browser
apm_web_var(s,a);

%% Generate a contour plot

% mesh points for x2 and x4
x = [1:0.1:5];
y = [1:0.1:5];
[x2,x4] = meshgrid(x,y);

% record fixed optimal values
x1 = solution.x1;
x3 = solution.x3;

% objective function
% minimize x1*x4*(x1+x2+x3) + x3
obj = x1 .* x4 .* (x1+x2+x3) + x3;

% inequality constraint: 
% x1*x2*x3*x4 > 25
ic = x1 .* x2 .* x3 .* x4;

% equality constraint: 
% x1^2 + x2^2 + x3^2 + x4^2 = 40
eq = x1.^2 + ...
	 x2.^2 + ...
	 x3.^2 + ...
	 x4.^2;

% create contour plot
figure(1)
title('NLP Contour Plot');
[C,h] = contour(x2,x4,obj);
clabel(C,h,'Labelspacing',200);
xlabel('x_2');
ylabel('x_4');
hold on;
[C,h] = contour(x2,x4,ic,...
	[25,25],...
	'b-',...
	'LineWidth',3);
clabel(C,h,'Labelspacing',200);
[C,h] = contour(x2,x4,eq,[40,40],...
	'r-',...
	'LineWidth',3);
clabel(C,h,'Labelspacing',200);

% show a legend
legend('Objective',...
       'x1*x2*x3*x4>25',...
	   'x_1^2+x_2^2+x_3^2+x_4^2=40')
% thin lines to show feasible region
contour(x2,x4,ic,[25,26,27],'b.-');
