# import packages
import matplotlib
import numpy as np
import matplotlib.pyplot as plt
from random import randint
from apm import *

# server
s = 'http://xps.apmonitor.com'

# application name + random number
a = 'demo' + str(randint(2,999))

# clear server
apm(s,a,'clear all')

# load model
apm_load(s,a,'nlp.apm')

# change the solver
# (1=APOPT, 2=BPOPT, 3=IPOPT)
apm_option(s,a,'nlc.solver',3)

# solve
output = apm(s,a,'solve')
print output

# retrieve solution
(csv,solution) = apm_sol(s,a)
print csv


# open application root files
apm_web_root(s,a)

# open solution in web browser
apm_web_var(s,a)

## Generate a contour plot

# mesh points for x2 and x4
x = np.arange(1.0, 5.0, 0.1)
y = np.arange(1.0, 5.0, 0.1)
x2, x4 = np.meshgrid(x, y)

# record fixed optimal values
x1 = solution['x1']
x3 = solution['x3']

# objective function:
# minimize x1*x4*(x1+x2+x3) + x3
obj = x1 * x4 * (x1+x2+x3) + x3

# inequality constraint: 
# x1*x2*x3*x4 > 25
ic = x1 * x2 * x3 * x4

# equality constraint:
# x1^2 + x2^2 + x3^2 + x4^2 = 40
eq = np.power(x1,2) + \
     np.power(x2,2) + \
     np.power(x3,2) + \
     np.power(x4,2)

# create contour plot
plt.figure()
plt.title('NLP Contour Plot')
CS = plt.contour(x2,x4,obj)
plt.clabel(CS,inline=1,fontsize=10)
plt.xlabel('x_2')
plt.ylabel('x_4')

CS = plt.contour(x2,x4,ic, \
	[25.0,26.0,27.0,28.0], \
	colors='b', \
	linewidths=[4.0,3.0,2.0,1.0])
plt.clabel(CS, inline=1, fontsize=10)
CS = plt.contour(x2,x4,eq,[40.0], \
	colors='r', \
	linewidths=[4.0])
plt.clabel(CS,inline=1,fontsize=10)
plt.savefig('contour.png')

# don't show legend

# display the plots
plt.show()


